;; Generated package description from aidermacs.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "aidermacs" "1.9" "AI pair programming with Aider" '((emacs "26.1") (transient "0.3.0") (compat "30.0.2.0") (markdown-mode "2.7")) :commit "6accda816d4726f0d4d24ebc49a458f9bb9c6899" :authors '(("Mingde Zeng" . "matthewzmd@posteo.net")) :maintainer '("Mingde Zeng" . "matthewzmd@posteo.net") :keywords '("ai" "emacs" "llm" "aider" "ai-pair-programming" "tools") :url "https://github.com/MatthewZMD/aidermacs")
